==> swf-visualizer-0.1.3.tgz: package/src/components/visualizer-info/visualization-options/sample-room-info-modal/sample-room-info-modal.jsx <==
import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { getEndpointBaseURL } from '@services/environment';

// import { useLoader } from '@services/LoaderContext';
import getHeaders from '@services/headersService';
import LocalStorage from '@services/local-storage';
import { Container, Modal, Image } from 'react-bootstrap';
import VisualizationInfo from '@services/visualization-info';
import RoomFooter from '../room-footer/room-footer';
import RedHeart from '@assets/images/Visualizers-images/red_heart.png';
import CloseIcon from '@assets/images/Visualizers-images/close-icon.svg';
import './sample-room-info-modal.scss';

const SampleRoomInfoModal = ({
  modalTitle,
  isShow,
  onPopupClose,
  onSelect,
  isFromSavedProjects
}) => {
  const [roomDetails, setRoomDetails] = useState({ loading: true, data: null });
  const [popupIsOpen, setPopupIsOpen] = useState(isShow);
  const timeStamps = isFromSavedProjects
    ? VisualizationInfo.getTimeStamps('savedProjects')
    : [];

  // const { showLoader, hideLoader } = useLoader();
  useEffect(() => {
    const fetchData = async () => {
      try {
        // showLoader();
        const response = await axios.get(`${getEndpointBaseURL()}sampleRoom`, { headers: getHeaders() });
       setRoomDetails({ loading: false, data: response.data.data });
      //  hideLoader();
      } catch (error) {
        // hideLoader();
        console.error("Error fetching sample room data:", error);
        setRoomDetails({ loading: false, data: null, error: true });
      }
    };
  
    if (!isFromSavedProjects) {
      fetchData();
    } else {
      getSavedProjects();
    }
  }, []);
    
  const handleClose = () => {
    setPopupIsOpen(false);
    onPopupClose();
  };

  const getFavListFromProductHandler = (item) => {
    const favList = VisualizationInfo.getSavedByTimeStamp('savedProjects', item)?.products
      ?.filter((obj) => Object.keys(obj).includes('favourites'));
    return favList;
  };

  const itemSelectHandler = (item, index) => {
    const timeStamp = isFromSavedProjects
      ? VisualizationInfo.getTimeStamps('savedProjects')[index]
      : Date.now();
    setPopupIsOpen(false);
    onSelect({ [timeStamp]: { sampleRoom: item } });
  };

  const deleteSavedRoom = (timeStamp, indexToRemove) => {
    const updatedRoomDetails = { ...roomDetails };
    updatedRoomDetails.data.splice(indexToRemove, 1);
    setRoomDetails(updatedRoomDetails);
    
    let parseData = LocalStorage.get('savedProjects');
    parseData.forEach((vak, index)=>{
      if(Object.keys(vak).toString() === timeStamp) {
        parseData.splice(index, 1)
      }
    });

    LocalStorage.set('savedProjects', parseData);
  }

  const getSavedProjects = () => {
    const parseData = LocalStorage.get('savedProjects');
    const data = VisualizationInfo.getSavedProjectByKey('sampleRoom', parseData);
    setRoomDetails({loading: false, data });
  }

  return (
    <Modal
      backdrop='static'
      keyboard={false}
      aria-labelledby='contained-modal-title-vcenter'
      onHide={handleClose}
      show={popupIsOpen}
      className='sample-room-info-container'
    >
      <Modal.Header>
        <img className='close-icon ' src={CloseIcon} alt='close-icon' onClick={handleClose} />
        <Modal.Title id='contained-modal-title-vcenter'>{modalTitle}</Modal.Title>
      </Modal.Header>
      <Modal.Body className='grid-example scrollable-body'>
        {roomDetails?.loading ? (
          <></>
        ) : (
          <Container>
            <ul className='image-container'>
              {roomDetails?.data?.map((item, idx) => (
                <li key={idx}>
                  {isFromSavedProjects && (
                    <div className='fav-icon-container'>
                      {getFavListFromProductHandler(timeStamps[idx])?.map((item, index) => (
                        <span className='hrt-ico' key={index}>
                          <img className='img-heart' src={RedHeart} alt='' />
                        </span>
                      ))}
                    </div>
                  )}
                  <Image
                    className='images'
                    src={item.file_path}
                    width='100%'
                    height='100%'
                    style={{ cursor: 'pointer' }}
                    onClick={() => itemSelectHandler(item, idx)}
                  />
                  {isFromSavedProjects && (
                    <RoomFooter
                      key={idx}
                      info={timeStamps[idx]}
                      onSelect={() => deleteSavedRoom(timeStamps[idx], idx)}
                    />
                  )}
                </li>
              ))}
            </ul>
          </Container>
        )}
      </Modal.Body>
    </Modal>
  );
};

export default SampleRoomInfoModal;

==> swf-visualizer-0.4.0.tgz: package/src/components/visualizer-info/visualization-options/sample-room-info-modal/sample-room-info-modal.jsx <==
import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { getEndpointBaseURL } from '@services/environment';

import { useLoader } from '@services/LoaderContext';
import getHeaders from '@services/headersService';
import LocalStorage from '@services/local-storage';
import { Container, Modal, Image } from 'react-bootstrap';
import VisualizationInfo from '@services/visualization-info';
import RoomFooter from '../room-footer/room-footer';
import RedHeart from '../../../../assets/images/Visualizers-images/red_heart.png';
import CloseIcon from '../../../../assets/images/Visualizers-images/close-icon.svg';
import './sample-room-info-modal.scss';

const SampleRoomInfoModal = ({
  modalTitle,
  isShow,
  onPopupClose,
  onSelect,
  isFromSavedProjects
}) => {
  const [roomDetails, setRoomDetails] = useState({ loading: true, data: null });
  const [popupIsOpen, setPopupIsOpen] = useState(isShow);
  const timeStamps = isFromSavedProjects
    ? VisualizationInfo.getTimeStamps('savedProjects')
    : [];

  const { showLoader, hideLoader } = useLoader();
  useEffect(() => {
    const fetchData = async () => {
      try {
        showLoader();
        const response = await axios.get(`${getEndpointBaseURL()}sampleRoom`, { headers: getHeaders() });
       setRoomDetails({ loading: false, data: response.data.data });
       hideLoader();
      } catch (error) {
        hideLoader();
        console.error("Error fetching sample room data:", error);
        setRoomDetails({ loading: false, data: null, error: true });
      }
    };
  
    if (!isFromSavedProjects) {
      fetchData();
    } else {
      getSavedProjects();
    }
  }, []);
    
  const handleClose = () => {
    setPopupIsOpen(false);
    onPopupClose();
  };

  const getFavListFromProductHandler = (item) => {
    const favList = VisualizationInfo.getSavedByTimeStamp('savedProjects', item)?.products
      ?.filter((obj) => Object.keys(obj).includes('favourites'));
    return favList;
  };

  const itemSelectHandler = (item, index) => {
    const timeStamp = isFromSavedProjects
      ? VisualizationInfo.getTimeStamps('savedProjects')[index]
      : Date.now();
    setPopupIsOpen(false);
    onSelect({ [timeStamp]: { sampleRoom: item } });
  };

  const deleteSavedRoom = (timeStamp, indexToRemove) => {
    const updatedRoomDetails = { ...roomDetails };
    updatedRoomDetails.data.splice(indexToRemove, 1);
    setRoomDetails(updatedRoomDetails);
    
    let parseData = LocalStorage.get('savedProjects');
    parseData.forEach((vak, index)=>{
      if(Object.keys(vak).toString() === timeStamp) {
        parseData.splice(index, 1)
      }
    });

    LocalStorage.set('savedProjects', parseData);
  }

  const getSavedProjects = () => {
    const parseData = LocalStorage.get('savedProjects');
    const data = VisualizationInfo.getSavedProjectByKey('sampleRoom', parseData);
    setRoomDetails({loading: false, data });
  }

  return (
    <Modal
      backdrop='static'
      keyboard={false}
      aria-labelledby='contained-modal-title-vcenter'
      onHide={handleClose}
      show={popupIsOpen}
      className='sample-room-info-container'
    >
      <Modal.Header>
        <img className='close-icon ' src={CloseIcon} alt='close-icon' onClick={handleClose} />
        <Modal.Title id='contained-modal-title-vcenter'>{modalTitle}</Modal.Title>
      </Modal.Header>
      <Modal.Body className='grid-example scrollable-body'>
        {roomDetails?.loading ? (
          <></>
        ) : (
          <Container>
            <ul className='image-container'>
              {roomDetails?.data?.map((item, idx) => (
                <li key={idx}>
                  {isFromSavedProjects && (
                    <div className='fav-icon-container'>
                      {getFavListFromProductHandler(timeStamps[idx])?.map((item, index) => (
                        <span className='hrt-ico' key={index}>
                          <img className='img-heart' src={RedHeart} alt='' />
                        </span>
                      ))}
                    </div>
                  )}
                  <Image
                    className='images'
                    src={item.file_path}
                    width='100%'
                    height='100%'
                    style={{ cursor: 'pointer' }}
                    onClick={() => itemSelectHandler(item, idx)}
                  />
                  {isFromSavedProjects && (
                    <RoomFooter
                      key={idx}
                      info={timeStamps[idx]}
                      onSelect={() => deleteSavedRoom(timeStamps[idx], idx)}
                    />
                  )}
                </li>
              ))}
            </ul>
          </Container>
        )}
      </Modal.Body>
    </Modal>
  );
};

export default SampleRoomInfoModal;
